@@ -1,7 +1,9 @@
 import pylibmc
 
+from sparta.memcached.base import SpartaCache
 
-class KeyPrefixWrapper:
+
+class SpartaCacheWrapper(SpartaCache):
     """
     Wrapper around pylibmc.Client to support key_prefix.
     Also see https://github.com/memcached/memcached/wiki/Commands.
@@ -12,12 +14,8 @@ class KeyPrefixWrapper:
         client: pylibmc.Client,
         key_prefix: str,
     ):
-        super().__init__()
+        super().__init__(key_prefix)
         self.client = client
-        self.key_prefix = key_prefix if isinstance(key_prefix, str) else str(key_prefix)
-
-    def _map_key(self, key):
-        return self.key_prefix + key if self.key_prefix else key
 
     def __repr__(self):
         return "<%s for %s>" % (self.__class__.__name__, self.client)
